from .produto_model import Produto

__all__ = ["Produto"]
